<?php
/**
 * bootstrap_starter_theme functions and definitions
 *
 * @package bootstrap_starter_theme
 */


/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

if ( ! function_exists( 'bootstrap_starter_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function bootstrap_starter_theme_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on bootstrap_starter_theme, use a find and replace
	 * to change 'bootstrap_starter_theme' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'bootstrap_starter_theme', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'homepage', 720, 560, true );
	add_image_size( 'single', 1200, 720, true );
	
	add_theme_support( 'title-tag' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'bootstrap_starter_theme' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	//add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	/**
	 * Setup the WordPress core custom background feature.
	 */
/*
	add_theme_support( 'custom-background', apply_filters( 'bootstrap_starter_theme_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
*/
}
endif; // bootstrap_starter_theme_setup
add_action( 'after_setup_theme', 'bootstrap_starter_theme_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function bootstrap_starter_theme_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'bootstrap_starter_theme' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	));
	
	register_sidebar(array(
		'name' => 'Footer',
		'id' => 'sidebar-2',
		'before_widget' => '<div class="botwid col-xs-6 col-md-3 %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="bothead">',
		'after_title' => '</h3>',
	));	
}
add_action( 'widgets_init', 'bootstrap_starter_theme_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function bootstrap_starter_theme_scripts() {
	wp_enqueue_style( 'bootstrap_starter_theme-style', get_stylesheet_uri() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css');
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
	wp_enqueue_style( 'pushy', get_template_directory_uri() . '/css/pushy.css');
	wp_enqueue_style( 'jscroll', get_template_directory_uri() . '/css/jscroll.css');
	wp_enqueue_style( 'theme', get_template_directory_uri() . '/css/theme.css');
	
	wp_enqueue_script('jquery');
	wp_enqueue_script( 'modernizer', get_template_directory_uri() . '/js/modernizr-2.6.2.min.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'mobilemenu', get_template_directory_uri() . '/js/mobilemenu.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'jscroll', get_template_directory_uri() . '/js/jscroll.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'mousewheel', get_template_directory_uri() . '/js/mouse-wheel.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'pushy', get_template_directory_uri() . '/js/pushy.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'custom', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'bootstrap_starter_theme-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}


}
add_action( 'wp_enqueue_scripts', 'bootstrap_starter_theme_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Pagination
 */
require get_template_directory() . '/inc/paginate.php';

/**
 * Include Aqua Resizer
 */
//require get_template_directory() . '/inc/aq_resizer.php';
